@@ -1264,286 +1264,3 @@ class APITests(BaseTests):
                 'ruleset': 'ruleset2'
             }), content_type="application/json", HTTP_AUTHORIZATION=auth)
         self.assertResponse(response, 200)
-
-if hasattr(settings, 'SOCRATES_OVIRT_USERNAME') and 'SOCRATES_OVIRT_URL' in os.environ:
-    class OVirtTests(BaseTests):
-        def create_ovirt_objects(self):
-            user, auth = self.create_basic_objects()
-            hypervisor = {
-                "state": "in-use",
-                "asset_type": "server",
-                "version": 1,
-                "service_tag": "C75T95J",
-                "owner": "group",
-                "provisioning": False,
-                "provision": {
-                    "os": "centos7",
-                    "hostname": "hypervisor.domain",
-                    "vlan": {
-                        "cidr": "10.0.1.0/24"
-                    },
-                    "storage": {
-                        "os": {
-                            "raid": "RAID-1",
-                            "controller_id": "0",
-                            "pdisks": []
-                        }
-                    }
-                },
-                "storage": [
-                    {"id": "0"}
-                ],
-                "nics": [
-                    {
-                        "mac": "90:e2:ba:81:7e:48",
-                        "remote": {
-                            "domain": "qfabric",
-                            "port": "ge-0/0/43.0"
-                        },
-                        "name": "p1p1"
-                    },
-                    {
-                        "mac": "90:e2:ba:81:7e:49",
-                        "remote": {
-                            "domain": "qfabric",
-                            "port": "ge-1/0/43.0"
-                        },
-                        "name": "p1p2"
-                    }
-                ],
-                "log": "Add hypervisor"
-            }
-            response = self.client.post('/asset/', data=json.dumps(hypervisor), content_type="application/json", HTTP_AUTHORIZATION=auth)
-            self.assertResponse(response, 201)
-            vmcluster = {
-                'asset_type': 'vmcluster',
-                'service_tag': 'oVirtTest',
-                'state': 'in-use',
-                'asset_subtype': 'ovirt',
-                'version': 1,
-                'owner': 'group',
-                'url': os.environ['SOCRATES_OVIRT_URL'],
-                'hypervisors': ['C75T95J'],
-                'storage': [{'datastores': {'Local': ['Data']}}],
-                'log': 'Add oVirt test cluster'
-            }
-            response = self.client.post('/asset/', data=json.dumps(vmcluster), content_type="application/json", HTTP_AUTHORIZATION=auth)
-            self.assertResponse(response, 201)
-            response = self.client.patch('/network/10.0.93.0/27', data=json.dumps({
-                    "domains": [{'domain': 'oVirtTest', 'name': 'br44'}]
-                }), content_type="application/json", HTTP_AUTHORIZATION=auth)
-            self.assertResponse(response, 200)
-            return user, auth
-
-        def test_ovirt_provision_vm(self):
-            user, auth = self.create_ovirt_objects()
-            vm = {
-                'asset_type': 'vm',
-                'parent': 'oVirtTest',
-                'version': 1,
-                'state': 'ready',
-                'owner': 'group',
-                'service_tag': 'service-tag-ovirt-test-1',
-                'provision': {
-                    'os': 'centos7',
-                    'vlan': {'cidr': '10.0.93.0/27'},
-                    'hostname': 'socrates-test-ovirt%s.domain' % random.randint(0, 9),
-                    'ram': 2*1024*1024*1024,
-                    'cpus': 1,
-                    'storage': {
-                        'os': {
-                            'by_id': 'sda',
-                            'size': 25*1000*1000*1000,
-                            'class': 'Local'
-                        },
-                        'data1': {
-                            'by_id': 'sdb',
-                            'size': 2*1000*1000*1000,
-                            'class': 'Local'
-                        }
-                    }
-                },
-                'provisioning': True,
-                'log': 'Add VM'
-            }
-            response = self.client.post('/asset/', data=json.dumps(vm), content_type="application/json", HTTP_AUTHORIZATION=auth)
-            self.assertResponse(response, 201)
-            data = json.loads(response.content)
-
-            try:
-                response = self.client.get('/asset/%s' % data['id'], accept="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-                data = json.loads(response.content)
-
-                response = self.client.post('/asset/%s/ipmi' % data['id'], data=json.dumps({'log': 'Power off VM', 'action': 'shutdown'}), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-
-                response = self.client.get('/asset/%s/ipmi' % data['id'], HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-                data2 = json.loads(response.content)
-                self.assertEqual(data2['power_state'], 'off')
-
-                response = self.client.get('/tkickstartcomplete/%s' % data['service_tag'])
-                self.assertResponse(response, 200)
-                self.assertEqual(response.content, 'true')
-
-                response = self.client.post('/asset/%s/ipmi' % data['id'], data=json.dumps({'log': 'Power off VM', 'action': 'shutdown'}), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-
-                response = self.client.get('/asset/%s' % data['id'], accept="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-                data = json.loads(response.content)
-
-                vm = copy.deepcopy(data)
-                del vm['provision']['storage']['data1']
-                vm['provision']['storage']['os']['size'] += 1*1000*1000*1000
-                vm['provision']['storage']['data2'] = {'by_id': 'sdc', 'size': 3*1000*1000*1000, 'class': 'Local'}
-                vm['provision']['cpus'] = 2
-                vm['provisioning'] = True
-                vm['log'] = 'Reprovision VM'
-                response = self.client.put('/asset/%s' % data['id'], data=json.dumps(vm), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-
-                response = self.client.get('/asset/%s' % data['id'], accept="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-                data = json.loads(response.content)
-                self.assertEqual(len(data['cpu']), vm['provision']['cpus'])
-                self.assertEqual(len([1 for x in data['storage'] if x['filename'].endswith('_data2')]), 1)
-                self.assertEqual(len(data['storage']), 2)
-                self.assertEqual(abs([x for x in data['storage'] if x['filename'].endswith('_os')][0]['capacity'] - vm['provision']['storage']['os']['size']) < 1024, True)
-            finally:
-                response = self.client.delete('/asset/%s' % data['id'], data=json.dumps({'log': 'Remove VM'}), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 204)
-                response = self.client.patch('/network/10.0.93.0/27', data=json.dumps({
-                    "domains": []
-                }), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-
-if 'SOCRATES_LIBVIRT_URL' in os.environ and 'SOCRATES_LIBVIRT_STORAGE' in os.environ:
-    class LibvirtTests(BaseTests):
-        networks = ['10.0.0.0/24', '10.0.1.0/24', '10.0.93.0/27']
-        def create_libvirt_objects(self):
-            user, auth = self.create_basic_objects()
-            hypervisor = {
-                'asset_type': 'server',
-                'service_tag': 'CZJ34902PL',
-                'state': 'in-use',
-                'version': 1,
-                'owner': 'group',
-                'nics': [
-                    {'remote': {'domain': 'qfabric', 'port': '1'}, 'name': 'eth0'}
-                ],
-                'log': 'Add hypervisor',
-            }
-            response = self.client.post('/asset/', data=json.dumps(hypervisor), content_type="application/json", HTTP_AUTHORIZATION=auth)
-            vmcluster = {
-                'asset_type': 'vmcluster',
-                'service_tag': 'libvirttest',
-                'state': 'in-use',
-                'asset_subtype': 'libvirt',
-                'version': 1,
-                'owner': 'group',
-                'url': os.environ['SOCRATES_LIBVIRT_URL'],
-                'hypervisors': [hypervisor['service_tag']],
-                'storage': [{'datastores': {'Local': [os.environ['SOCRATES_LIBVIRT_STORAGE']]}}],
-                'nics': [{'name': 'bond0'}],
-                'log': 'Add libvirt test cluster'
-            }
-            response = self.client.post('/asset/', data=json.dumps(vmcluster), content_type="application/json", HTTP_AUTHORIZATION=auth)
-            self.assertResponse(response, 201)
-            self.domains = {}
-            for network in self.networks:
-                self.domains[network] = json.loads(self.client.get('/network/0/' + network, HTTP_AUTHORIZATION=auth).content)
-                response = self.client.patch('/network/0/' + network, data=json.dumps({
-                        "domains": {'libvirttest': {'name': self.domains[network]['domains']['qfabric']['name'], 'vlan_id': self.domains[network]['domains']['qfabric']['vlan_id']}}
-                    }), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-            return user, auth
-
-        def test_libvirt_provision_vm(self):
-            user, auth = self.create_libvirt_objects()
-            vm = {
-                'asset_type': 'vm',
-                'parent': 'libvirttest',
-                'version': 1,
-                'state': 'ready',
-                'owner': 'group',
-                'service_tag': 'service-tag-libvirt-test-1',
-                'provision': {
-                    'os': 'centos7',
-                    'vlan': {'cidr': '10.0.93.0/27'},
-                    'vlans': [{'cidr': '10.0.0.0/24'}],
-                    'hostname': 'socrates-test-libvirt%s.domain' % random.randint(0, 9),
-                    'ram': 2*1024*1024*1024,
-                    'cpus': 1,
-                    'storage': {
-                        'os': {
-                            'by_id': 'sda',
-                            'size': 25031606272,
-                            'class': 'Local'
-                        },
-                        'data1': {
-                            'by_id': 'sdb',
-                            'size': 2*1000*1000*1000,
-                            'class': 'Local'
-                        }
-                    }
-                },
-                'provisioning': True,
-                'log': 'Add VM'
-            }
-            response = self.client.post('/asset/', data=json.dumps(vm), content_type="application/json", HTTP_AUTHORIZATION=auth)
-            self.assertResponse(response, 201)
-            data = json.loads(response.content)
-
-            response = self.client.post(r'/task/invoke/socrates_api.tasks.collect_networks', HTTP_AUTHORIZATION=auth)
-            self.assertResponse(response, 204)
-
-            try:
-                response = self.client.get('/asset/%s' % data['id'], accept="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-                data = json.loads(response.content)
-
-                response = self.client.get('/tkickstartcomplete/%s' % data['service_tag'])
-                self.assertResponse(response, 200)
-                self.assertEqual(response.content, 'true')
-
-                response = self.client.post('/asset/%s/ipmi' % data['id'], data=json.dumps({'log': 'Power off VM', 'action': 'shutdown'}), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-
-                response = self.client.get('/asset/%s' % data['id'], accept="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-                data = json.loads(response.content)
-
-                vm = copy.deepcopy(data)
-                del vm['provision']['storage']['data1']
-                vm['provision']['storage']['os']['size'] += 1*1000*1000*1000
-                vm['provision']['storage']['data2'] = {'by_id': 'sdc', 'size': 3*1000*1000*1000, 'class': 'Local'}
-                vm['provision']['cpus'] = 2
-                vm['provision']['ram'] += 128*1024*1024
-                vm['provision']['vlans'] = [{'cidr': '10.0.1.0/24'}]
-                vm['provisioning'] = True
-                vm['log'] = 'Reprovision VM'
-                response = self.client.put('/asset/%s' % data['id'], data=json.dumps(vm), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-
-                response = self.client.get('/asset/%s' % data['id'], accept="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 200)
-                data = json.loads(response.content)
-                self.assertEqual(len(data['cpu']), vm['provision']['cpus'])
-                self.assertEqual(len([1 for x in data['storage'] if '_data2' in x['filename']]), 1)
-                self.assertEqual(len(data['storage']), 2)
-                self.assertEqual(abs([x for x in data['storage'] if '_os' in x['filename']][0]['capacity'] - vm['provision']['storage']['os']['size']) < 1024, True)
-                self.assertEqual(data['ram']['total'], vm['provision']['ram'])
-
-                response = self.client.post(r'/task/invoke/socrates_api.tasks.collect_all_vms', HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 204)
-            finally:
-                response = self.client.delete('/asset/%s' % data['id'], data=json.dumps({'log': 'Remove VM'}), content_type="application/json", HTTP_AUTHORIZATION=auth)
-                self.assertResponse(response, 204)
-                for network in self.networks:
-                    self.domains[network]['version'] = json.loads(self.client.get('/network/0/' + network, HTTP_AUTHORIZATION=auth).content)['version']
-                    response = self.client.put('/network/0/' + network,
-                        data=json.dumps(self.domains[network]),
-                        content_type="application/json", HTTP_AUTHORIZATION=auth)
-                    self.assertResponse(response, 200)
